-----------------------------------------------------------
--Search and Replace All as follows:
-- 1) Replace <DB> with the name of the database to create.
--    (e.g., Substitute RT for <DB> be sure to delete the angle brackets)
-- 2) Replace <PATH> with the full path to this file and 
--    others associated with it. Ensure it ends with a 
--    backslash. e.g., replace <PATH> with C:\MyDatabases\
-----------------------------------------------------------
--
IF NOT EXISTS(SELECT * FROM sys.databases
          WHERE name = N'<DB>')
	CREATE DATABASE <DB>
GO
USE <DB>
--
-- Alter the path so the script can find the CSV files
--
DECLARE
   @data_path nvarchar(256);
SELECT @data_path = '<PATH>';
--
--GO
-- =======================================
-- Delete existing tables
--
If Exists(SELECT * FROM sys.tables WHERE name = N'TempDateMade') drop table TempDateMade;
If Exists(SELECT * FROM sys.tables WHERE name = N'StateTaxRate') drop table StateTaxRate;
If Exists(SELECT * FROM sys.tables WHERE name = N'CensusRegion') drop table CensusRegion;
If Exists(SELECT * FROM sys.tables WHERE name = N'CensusDivision') drop table CensusDivision;
If Exists(SELECT * FROM sys.tables WHERE name = N'RevisionHistory') drop table RevisionHistory;
If Exists(SELECT * FROM sys.tables WHERE name = N'PurchaseItem') drop table PurchaseItem;
If Exists(SELECT * FROM sys.tables WHERE name = N'PurchaseOrder') drop table PurchaseOrder;
If Exists(SELECT * FROM sys.tables WHERE name = N'ManufacturerTransaction') drop table ManufacturerTransaction;
If Exists(SELECT * FROM sys.tables WHERE name = N'GroupComponents') drop table GroupComponents;
If Exists(SELECT * FROM sys.tables WHERE name = N'CustomerTransaction') drop table CustomerTransaction;
If Exists(SELECT * FROM sys.tables WHERE name = N'BikeTubes') drop table BikeTubes;
If Exists(SELECT * FROM sys.tables WHERE name = N'BikeParts') drop table BikeParts;
If Exists(SELECT * FROM sys.tables WHERE name = N'BicycleTubeUsage') drop table BicycleTubeUsage;
If Exists(SELECT * FROM sys.tables WHERE name = N'Bicycle') drop table Bicycle;
If Exists(SELECT * FROM sys.tables WHERE name = N'LetterStyle') drop table LetterStyle;
If Exists(SELECT * FROM sys.tables WHERE name = N'Groupo') drop table Groupo;
If Exists(SELECT * FROM sys.tables WHERE name = N'Preference') drop table Preference;
If Exists(SELECT * FROM sys.tables WHERE name = N'CommonSizes') drop table CommonSizes;
If Exists(SELECT * FROM sys.tables WHERE name = N'Paint') drop table Paint;
If Exists(SELECT * FROM sys.tables WHERE name = N'TubeMaterial') drop table TubeMaterial;
If Exists(SELECT * FROM sys.tables WHERE name = N'Component') drop table Component;
If Exists(SELECT * FROM sys.tables WHERE name = N'ComponentName') drop table ComponentName;
If Exists(SELECT * FROM sys.tables WHERE name = N'ModelSize') drop table ModelSize;
If Exists(SELECT * FROM sys.tables WHERE name = N'ModelType') drop table ModelType;
If Exists(SELECT * FROM sys.tables WHERE name = N'Customer') drop table Customer;
If Exists(SELECT * FROM sys.tables WHERE name = N'RetailStore') drop table RetailStore;
If Exists(SELECT * FROM sys.tables WHERE name = N'Employee') drop table Employee;
If Exists(SELECT * FROM sys.tables WHERE name = N'WorkArea') drop table WorkArea;
If Exists(SELECT * FROM sys.tables WHERE name = N'Manufacturer') drop table Manufacturer;
If Exists(SELECT * FROM sys.tables WHERE name = N'City') drop table City;
--
-- Create tables
--
CREATE TABLE City
(
CityID        int,
ZipCode       nvarchar(150) NULL,
City          nvarchar(250) NULL,
State         nvarchar(250) NULL,
AreaCode      nvarchar(150) NULL,
Population2010              int
     DEFAULT 0 NULL,
Population2000              int
     DEFAULT 0 NULL,
Population1990              int
     DEFAULT 0 NULL,
Population1980              int
     DEFAULT 0 NULL,
Country       nvarchar(250) NULL,
Latitude      float
     DEFAULT 0 NULL,
Longitude     float
     DEFAULT 0 NULL,
SelectionCDF  float
     DEFAULT 0 NULL,
FIPS          int
     DEFAULT 0 NULL,
Income2009    money
     DEFAULT 0 NULL,
Income2004    money
     DEFAULT 0 NULL,
Division       int NULL,
StateCode      int NULL,
Region         int NULL,
IntPtLat       nvarchar(100) NULL,
IntPtLon       nvarchar(100) NULL,
Housing2010    int NULL,
AreaLand       nvarchar(100) NULL,
AreaWater      nvarchar(100) NULL,
     CONSTRAINT pk_City PRIMARY KEY (CityID)
);


CREATE TABLE Manufacturer
(
ManufacturerID              int,
ManufacturerName            nvarchar(150) NULL,
ContactName   nvarchar(150) NULL,
Phone         nvarchar(150) NULL,
Address       nvarchar(250) NULL,
ZipCode       nvarchar(150) NULL,
CityID        int
     DEFAULT 0 NULL,
BalanceDue    money
     DEFAULT 0 NULL,
     CONSTRAINT pk_Manufacturer PRIMARY KEY (ManufacturerID),
     CONSTRAINT fk_CityManufacturer FOREIGN KEY (CityID)
        REFERENCES City(CityID)
);


CREATE TABLE WorkArea
(
WorkArea      nvarchar(150),
Description   nvarchar(250) NULL,
     CONSTRAINT pk_WorkArea PRIMARY KEY (WorkArea)
);

CREATE TABLE Employee
(
EmployeeID    int
     DEFAULT 0,
TaxpayerID    nvarchar(150) NULL,
LastName      nvarchar(150) NULL,
FirstName     nvarchar(150) NULL,
HomePhone     nvarchar(150) NULL,
Address       nvarchar(150) NULL,
ZipCode       nvarchar(150) NULL,
CityID        int
     DEFAULT 0 NULL,
DateHired     datetime NULL,
DateReleased  datetime NULL,
CurrentManager              int
     DEFAULT 0 NULL,
SalaryGrade   int
     DEFAULT 0 NULL,
Salary        money
     DEFAULT 0 NULL,
Title         nvarchar(200) NULL,
WorkArea      nvarchar(150) NULL,
     CONSTRAINT pk_Employee PRIMARY KEY (EmployeeID),
     CONSTRAINT fk_CityEmployee FOREIGN KEY (CityID)
        REFERENCES City(CityID),
     CONSTRAINT fk_EmployeeWorkArea FOREIGN KEY (WorkArea)
        REFERENCES WorkArea(WorkArea)
);


CREATE TABLE RetailStore
(
StoreID       int,
StoreName     nvarchar(250) NULL,
Phone         nvarchar(150) NULL,
ContactFirstName            nvarchar(150) NULL,
ContactLastName             nvarchar(150) NULL,
Address       nvarchar(250) NULL,
ZipCode       nvarchar(150) NULL,
CityID        int
     DEFAULT 0 NULL,
     CONSTRAINT pk_RetailStore PRIMARY KEY (StoreID),
     CONSTRAINT fk_CityRetailStore FOREIGN KEY (CityID)
        REFERENCES City(CityID)
);

CREATE TABLE Customer
(
CustomerID    int,
Phone         nvarchar(150) NULL,
FirstName     nvarchar(150) NULL,
LastName      nvarchar(150) NULL,
Gender        nvarchar(150) NULL,
Address       nvarchar(150) NULL,
ZipCode       nvarchar(150) NULL,
CityID        int
     DEFAULT 0 NULL,
BalanceDue    money
     DEFAULT 0 NULL,
     CONSTRAINT pk_Customer PRIMARY KEY (CustomerID),
     CONSTRAINT fk_CityCustomer FOREIGN KEY (CityID)
        REFERENCES City(CityID)
);

CREATE TABLE ModelType
(
ModelType     nvarchar(150),
Description   nvarchar(250) NULL,
ComponentID   int
     DEFAULT 0 NULL,
     CONSTRAINT pk_ModelType PRIMARY KEY (ModelType)
);

CREATE TABLE ModelSize
(
ModelType     nvarchar(150),
MSize         float
     DEFAULT 0 ,
TopTube       float
     DEFAULT 0 NULL,
ChainStay     float
     DEFAULT 0 NULL,
TotalLength   float
     DEFAULT 0 NULL,
GroundClearance             float
     DEFAULT 0 NULL,
HeadTubeAngle float
     DEFAULT 0 NULL,
SeatTubeAngle float
     DEFAULT 0 NULL,
     CONSTRAINT pk_ModelSize PRIMARY KEY (ModelType,MSize),
     CONSTRAINT fk_Reference2 FOREIGN KEY (ModelType)
        REFERENCES ModelType(ModelType)
        ON DELETE CASCADE
);

CREATE TABLE ComponentName
(
ComponentName nvarchar(150),
AssemblyOrder int
     DEFAULT 0 NULL,
Description   nvarchar(250) NULL,
     CONSTRAINT pk_ComponentName PRIMARY KEY (ComponentName)
);

CREATE TABLE Component
(
ComponentID   int
     DEFAULT 0,
ManufacturerID              int
     DEFAULT 0 NULL,
ProductNumber nvarchar(150) NULL,
Road          nvarchar(150) NULL,
Category      nvarchar(150) NULL,
Length        float
     DEFAULT 0 NULL,
Height        float
     DEFAULT 0 NULL,
Width         float
     DEFAULT 0 NULL,
Weight        float
     DEFAULT 0 NULL,
Year          int
     DEFAULT 0 NULL,
EndYear       int
     DEFAULT 0 NULL,
Description   nvarchar(200) NULL,
ListPrice     money
     DEFAULT 0 NULL,
EstimatedCost money
     DEFAULT 0 NULL,
QuantityOnHand              float
     DEFAULT 10 NULL,
     CONSTRAINT pk_Component PRIMARY KEY (ComponentID),
     CONSTRAINT fk_Reference FOREIGN KEY (Category)
        REFERENCES ComponentName(ComponentName)
        ON DELETE CASCADE,
     CONSTRAINT fk_Reference16 FOREIGN KEY (ManufacturerID)
        REFERENCES Manufacturer(ManufacturerID)
        ON DELETE CASCADE
);

CREATE TABLE TubeMaterial
(
TubeID        int
     DEFAULT 0,
Material      nvarchar(150) NULL,
Description   nvarchar(200) NULL,
Diameter      real
     DEFAULT 0 NULL,
Thickness     real
     DEFAULT 0 NULL,
Roundness     nvarchar(150) NULL,
Weight        real
     DEFAULT 0 NULL,
Stiffness     real
     DEFAULT 0 NULL,
ListPrice     money
     DEFAULT 1 NULL,
Construction  nvarchar(150)
     DEFAULT N'Bonded' NULL,
     CONSTRAINT pk_TubeMaterial PRIMARY KEY (TubeID)
);

CREATE TABLE CommonSizes
(
ModelType     nvarchar(150),
FrameSize     real
     DEFAULT 0 ,
     CONSTRAINT pk_CommonSizes PRIMARY KEY (ModelType,FrameSize)
);

CREATE TABLE Paint
(
PaintID       int,
ColorName     nvarchar(150) NULL,
ColorStyle    nvarchar(150)
     DEFAULT N'Solid'
     CHECK (ColorStyle IN (N'Solid', N'Two Color', N'Three Color', N'Special')) NULL,
ColorList     nvarchar(250) NULL,
DateIntroduced              smalldatetime NULL,
DateDiscontinued            smalldatetime NULL,
     CONSTRAINT pk_Paint PRIMARY KEY (PaintID)
);

CREATE TABLE Preference
(
ItemName      nvarchar(250),
Value         real
     DEFAULT 0 NULL,
Description   nvarchar(500) NULL,
DateChanged   smalldatetime NULL,
     CONSTRAINT pk_Preference PRIMARY KEY (ItemName)
);

CREATE TABLE Groupo
(
ComponentGroupID            int,
GroupName     nvarchar(150) NULL,
BikeType      nvarchar(150) NULL,
Year          int NULL,
EndYear       int NULL,
WEIGHT        real NULL,
     CONSTRAINT pk_Groupo PRIMARY KEY (ComponentGroupID)
);

CREATE TABLE LetterStyle
(
LetterStyle   nvarchar(150),
Description   nvarchar(250) NULL,
     CONSTRAINT pk_LetterStyle PRIMARY KEY (LetterStyle)
);

CREATE TABLE Bicycle
(
SerialNumber  int,
CustomerID    int
     DEFAULT 0 NULL,
ModelType     nvarchar(150) NULL,
PaintID       int
     DEFAULT 0 NULL,
FrameSize     real
     DEFAULT 0 NULL,
OrderDate     smalldatetime NULL,
StartDate     smalldatetime NULL,
ShipDate      smalldatetime NULL,
ShipEmployee  int
     DEFAULT 0 NULL,
FrameAssembler              int
     DEFAULT 0 NULL,
Painter       int
     DEFAULT 0 NULL,
Construction  nvarchar(150)
     DEFAULT N'Bonded' NULL,
WaterBottleBrazeOns         int
     DEFAULT 4 NULL,
CustomName    nvarchar(250) NULL,
LetterStyleID nvarchar(150) NULL,
StoreID       int
     DEFAULT 0 NULL,
EmployeeID    int
     DEFAULT 0 NULL,
TopTube       real
     DEFAULT 0 NULL,
ChainStay     real
     DEFAULT 0 NULL,
HeadTubeAngle real
     DEFAULT 0 NULL,
SeatTubeAngle real
     DEFAULT 0 NULL,
ListPrice     money
     DEFAULT 0 NULL,
SalePrice     money
     DEFAULT 0 NULL,
SalesTax      money
     DEFAULT 0 NULL,
SaleState     nvarchar(150) NULL,
ShipPrice     money
     DEFAULT 0 NULL,
FramePrice    money
     DEFAULT 0 NULL,
ComponentList money
     DEFAULT 0 NULL,
     CONSTRAINT pk_Bicycle PRIMARY KEY (SerialNumber),
     CONSTRAINT fk_BikeModelType FOREIGN KEY (ModelType)
        REFERENCES ModelType(ModelType)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikeEmployee FOREIGN KEY (EmployeeID)
        REFERENCES Employee(EmployeeID)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikeRetail FOREIGN KEY (StoreID)
        REFERENCES RetailStore(StoreID)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikeCustomer FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikeLetter FOREIGN KEY (LetterStyleID)
        REFERENCES LetterStyle(LetterStyle)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikePaint FOREIGN KEY (PaintID)
        REFERENCES Paint(PaintID)
        ON DELETE CASCADE
);

CREATE TABLE BicycleTubeUsage
(
SerialNumber  int
     DEFAULT 0,
TubeID        int
     DEFAULT 0,
Quantity      real
     DEFAULT 0 NULL,
     CONSTRAINT pk_BicycleTubeUsage PRIMARY KEY (SerialNumber,TubeID),
     CONSTRAINT fk_BikeTubeBike FOREIGN KEY (SerialNumber)
        REFERENCES Bicycle(SerialNumber)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikeTubeMaterial FOREIGN KEY (TubeID)
        REFERENCES TubeMaterial(TubeID)
        ON DELETE CASCADE
);

CREATE TABLE BikeParts
(
SerialNumber  int
     DEFAULT 0,
ComponentID   int
     DEFAULT 0,
SubstituteID  int
     DEFAULT 0 NULL,
Location      nvarchar(150) NULL,
Quantity      int
     DEFAULT 0 NULL,
DateInstalled smalldatetime NULL,
EmployeeID    int
     DEFAULT 0 NULL,
     CONSTRAINT pk_BikeParts PRIMARY KEY (SerialNumber,ComponentID),
     CONSTRAINT fk_BikePartsBike FOREIGN KEY (SerialNumber)
        REFERENCES Bicycle(SerialNumber)
        ON DELETE CASCADE,
     CONSTRAINT fk_BikePartsEmp FOREIGN KEY (EmployeeID)
        REFERENCES Employee(EmployeeID)
        ON DELETE NO ACTION,
     CONSTRAINT fk_BikePartsComp FOREIGN KEY (ComponentID)
        REFERENCES Component(ComponentID)
        ON DELETE CASCADE
);

CREATE TABLE BikeTubes
(
SerialNumber  int
     DEFAULT 0,
TubeName      nvarchar(150)
     CHECK (TubeName IN (N'Top', N'Seat', N'Rear', N'Chain', N'Down', N'Front')),
TubeID        int
     DEFAULT 0 NULL,
Length        real
     DEFAULT 0 NULL,
     CONSTRAINT pk_BikeTubes PRIMARY KEY (SerialNumber,TubeName),
     CONSTRAINT fk_BikeTubesBike FOREIGN KEY (SerialNumber)
        REFERENCES Bicycle(SerialNumber)
        ON DELETE CASCADE,
     CONSTRAINT fk_TubeMaterialBikeTubes FOREIGN KEY (TubeID)
        REFERENCES TubeMaterial(TubeID)
        ON DELETE CASCADE
);

CREATE TABLE CustomerTransaction
(
CustomerID    int
     DEFAULT 0,
TransactionDate             smalldatetime,
EmployeeID    int
     DEFAULT 0 NULL,
Amount        money
     DEFAULT 0 NULL,
Description   nvarchar(500) NULL,
Reference     int
     DEFAULT 0 NULL,
     CONSTRAINT pk_CustomerTransaction PRIMARY KEY (CustomerID,TransactionDate),
     CONSTRAINT fk_CustTransCust FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE
);

CREATE TABLE GroupComponents
(
GroupID       int
     DEFAULT 0,
ComponentID   int
     DEFAULT 0,
     CONSTRAINT pk_GroupComponents PRIMARY KEY (GroupID,ComponentID),
     CONSTRAINT fk_GroupCompComp FOREIGN KEY (ComponentID)
        REFERENCES Component(ComponentID)
        ON DELETE CASCADE,
     CONSTRAINT fk_GroupCompGroup FOREIGN KEY (GroupID)
        REFERENCES Groupo(ComponentGroupID)
        ON DELETE CASCADE
);

CREATE TABLE ManufacturerTransaction
(
ManufacturerID              int
     DEFAULT 0,
TransactionDate             smalldatetime,
EmployeeID    int
     DEFAULT 0 NULL,
Amount        money
     DEFAULT 0 NULL,
Description   nvarchar(500) NULL,
Reference     int
     DEFAULT 0,
     CONSTRAINT pk_ManufTransaction PRIMARY KEY (ManufacturerID,TransactionDate,Reference),
     CONSTRAINT fk_ManufTrans FOREIGN KEY (ManufacturerID)
        REFERENCES Manufacturer(ManufacturerID)
        ON DELETE CASCADE
);

CREATE TABLE PurchaseOrder
(
PurchaseID    int,
EmployeeID    int
     DEFAULT 0 NULL,
ManufacturerID              int
     DEFAULT 0 NULL,
TotalList     money
     DEFAULT 0 NULL,
ShippingCost  money
     DEFAULT 0 NULL,
Discount      money
     DEFAULT 0 NULL,
OrderDate     smalldatetime NULL,
ReceiveDate   smalldatetime NULL,
AmountDue     money
     DEFAULT 0 NULL,
     CONSTRAINT pk_PurchaseOrder PRIMARY KEY (PurchaseID),
     CONSTRAINT fk_PurchOrderManuf FOREIGN KEY (ManufacturerID)
        REFERENCES Manufacturer(ManufacturerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_PurchOrderEmp FOREIGN KEY (EmployeeID)
        REFERENCES Employee(EmployeeID)
        ON DELETE CASCADE
);

CREATE TABLE PurchaseItem
(
PurchaseID    int
     DEFAULT 0,
ComponentID   int
     DEFAULT 0,
PricePaid     money
     DEFAULT 0 NULL,
Quantity      int
     DEFAULT 0 NULL,
QuantityReceived int
     DEFAULT 0 NULL,
     CONSTRAINT pk_PurchaseItem PRIMARY KEY (PurchaseID,ComponentID),
     CONSTRAINT fk_PurchItemPurch FOREIGN KEY (PurchaseID)
        REFERENCES PurchaseOrder(PurchaseID)
        ON DELETE CASCADE,
     CONSTRAINT fk_PurchItemComp FOREIGN KEY (ComponentID)
        REFERENCES Component(ComponentID)
        ON DELETE NO ACTION
);

CREATE TABLE RevisionHistory
(
ID            int,
Version       nvarchar(150) NULL,
ChangeDate    smalldatetime NULL,
Name          nvarchar(150) NULL,
RevisionComments            nvarchar(500) NULL,
     CONSTRAINT pk_RevisionHistory PRIMARY KEY (ID)
);

CREATE TABLE CensusRegion
(
RegionID        int,
RegionName      nvarchar(250) NULL,
     CONSTRAINT pk_CensusRegion PRIMARY KEY (RegionID)
);

CREATE TABLE CensusDivision
(
DivisionID     int,
DivisionName   nvarchar(250) NULL,
RegionID       int NULL,
     CONSTRAINT pk_CensusDivision PRIMARY KEY (DivisionID)
);

CREATE TABLE StateTaxRate
(
State         nvarchar(150),
TaxRate       real
     DEFAULT 0 NULL,
     CONSTRAINT pk_StateTaxRate PRIMARY KEY (State)
);

CREATE TABLE TempDateMade
(
DateValue     smalldatetime,
MadeCount     real
     DEFAULT 0 NULL,
     CONSTRAINT pk_TempDateMade PRIMARY KEY (DateValue)
);
--
-- Load table data
-- 1: City
--
EXECUTE (N'BULK INSERT City FROM ''' + @data_path + N'City.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');

-- 2: Manufacturer
EXECUTE (N'BULK INSERT Manufacturer FROM ''' + @data_path + N'Manufacturer.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 3: WorkArea
EXECUTE (N'BULK INSERT WorkArea FROM ''' + @data_path + N'WorkArea.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 4: Employee
EXECUTE (N'BULK INSERT Employee FROM ''' + @data_path + N'Employee.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 5: RetailStore
EXECUTE (N'BULK INSERT RetailStore FROM ''' + @data_path + N'RetailStore.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 6: Customer
EXECUTE (N'BULK INSERT Customer FROM ''' + @data_path + N'Customer.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 7: ModelType
EXECUTE (N'BULK INSERT ModelType FROM ''' + @data_path + N'ModelType.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 8: ModelSize
EXECUTE (N'BULK INSERT ModelSize FROM ''' + @data_path + N'ModelSize.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 9: ComponentName
EXECUTE (N'BULK INSERT ComponentName FROM ''' + @data_path + N'ComponentName.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 10: Component
EXECUTE (N'BULK INSERT Component FROM ''' + @data_path + N'Component.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 11: TubeMaterial
EXECUTE (N'BULK INSERT TubeMaterial FROM ''' + @data_path + N'TubeMaterial.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 12: CommonSizes
EXECUTE (N'BULK INSERT CommonSizes FROM ''' + @data_path + N'CommonSizes.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 13: Paint
EXECUTE (N'BULK INSERT Paint FROM ''' + @data_path + N'Paint.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 14: Preference
EXECUTE (N'BULK INSERT Preference FROM ''' + @data_path + N'Preference.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 15: Groupo
EXECUTE (N'BULK INSERT Groupo FROM ''' + @data_path + N'Groupo.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 16: LetterStyle
EXECUTE (N'BULK INSERT LetterStyle FROM ''' + @data_path + N'LetterStyle.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 17: Bicycle
EXECUTE (N'BULK INSERT Bicycle FROM ''' + @data_path + N'Bicycle.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 18: BicycleTubeUsage
EXECUTE (N'BULK INSERT BicycleTubeUsage FROM ''' + @data_path + N'BicycleTubeUsage.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 19: BikeParts
EXECUTE (N'BULK INSERT BikeParts FROM ''' + @data_path + N'BikeParts.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 20: BikeTubes
EXECUTE (N'BULK INSERT BikeTubes FROM ''' + @data_path + N'BikeTubes.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 21: CustomerTransaction
EXECUTE (N'BULK INSERT CustomerTransaction FROM ''' + @data_path + N'CustomerTransaction.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 22: GroupComponents
EXECUTE (N'BULK INSERT GroupComponents FROM ''' + @data_path + N'GroupComponents.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 23: ManufacturerTransaction
EXECUTE (N'BULK INSERT ManufacturerTransaction FROM ''' + @data_path + N'ManufacturerTransaction.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 24: PurchaseOrder
EXECUTE (N'BULK INSERT PurchaseOrder FROM ''' + @data_path + N'PurchaseOrder.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 25: PurchaseItem
EXECUTE (N'BULK INSERT PurchaseItem FROM ''' + @data_path + N'PurchaseItem.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 26: RevisionHistory
EXECUTE (N'BULK INSERT RevisionHistory FROM ''' + @data_path + N'RevisionHistory.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 27: CensusRegion
EXECUTE (N'BULK INSERT CensusRegion FROM ''' + @data_path + N'CensusRegion.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 28: CensusDivision
EXECUTE (N'BULK INSERT CensusDivision FROM ''' + @data_path + N'CensusDivision.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--

-- 29: StateTaxRate
EXECUTE (N'BULK INSERT StateTaxRate FROM ''' + @data_path + N'StateTaxRate.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
GO
-- ====================================
-- List the table names and row counts
SET NOCOUNT ON
SELECT 'Bicycle' "Table", COUNT(*) "Rows" FROM Bicycle        UNION
SELECT 'BicycleTubeUsage',   COUNT(*)  FROM BicycleTubeUsage  UNION
SELECT 'BikeParts',          COUNT(*)  FROM BikeParts         UNION
SELECT 'BikeTubes',          COUNT(*)  FROM BikeTubes         UNION
SELECT 'City',               COUNT(*)  FROM City              UNION
SELECT 'CommonSizes',        COUNT(*)  FROM CommonSizes       UNION
SELECT 'Component',          COUNT(*)  FROM Component         UNION
SELECT 'ComponentName',      COUNT(*)  FROM ComponentName     UNION
SELECT 'Customer',           COUNT(*)  FROM Customer          UNION
SELECT 'CustomerTransaction',COUNT(*)  FROM CustomerTransaction UNION
SELECT 'Employee',           COUNT(*)  FROM Employee          UNION
SELECT 'GroupComponents',    COUNT(*)  FROM GroupComponents   UNION
SELECT 'Groupo',             COUNT(*)  FROM Groupo            UNION
SELECT 'LetterStyle',        COUNT(*)  FROM LetterStyle       UNION
SELECT 'Manufacturer',       COUNT(*)  FROM Manufacturer      UNION
SELECT 'ManufacturerTransaction', COUNT(*)  FROM ManufacturerTransaction  UNION
SELECT 'ModelSize',          COUNT(*)  FROM ModelSize         UNION
SELECT 'ModelType',          COUNT(*)  FROM ModelType         UNION
SELECT 'Paint',              COUNT(*)  FROM Paint             UNION
SELECT 'Preference',         COUNT(*)  FROM Preference        UNION
SELECT 'PurchaseItem',       COUNT(*)  FROM PurchaseItem      UNION
SELECT 'PurchaseOrder',      COUNT(*)  FROM PurchaseOrder     UNION
SELECT 'RetailStore',        COUNT(*)  FROM RetailStore       UNION
SELECT 'RevisionHistory',    COUNT(*)  FROM RevisionHistory   UNION
SELECT 'CensusRegion',       COUNT(*)  FROM CensusRegion      UNION
SELECT 'CensusDivision',     COUNT(*)  FROM CensusDivision      UNION
SELECT 'StateTaxRate',       COUNT(*)  FROM StateTaxRate      UNION
SELECT 'TubeMaterial',       COUNT(*)  FROM TubeMaterial      UNION
SELECT 'WorkArea',           COUNT(*)  FROM WorkArea
ORDER BY 1;
SET NOCOUNT OFF
GO

